==> wssx-impl-2.4.0-sources.jar: com/sun/xml/wss/saml/Conditions.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

/*
 * Conditions.java
 *
 * Created on August 18, 2005, 12:31 PM
 *
 */

package com.sun.xml.wss.saml;

import java.util.Date;
import java.util.List;

/**
 *
 * @author abhijit.das@Sun.COM
 */

/**
 * The validity of an <code>Assertion</code> MAY be subject to a set of
 * <code>Conditions</code>. Each <code>Condition</code> evaluates to a value that
 * is Valid, Invalid or Indeterminate.
 *
 * <p>The following schema fragment specifies the expected content contained within 
 * SAML Conditions element.
 *
 * <pre>
 * &lt;complexType name="ConditionsType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice maxOccurs="unbounded" minOccurs="0"&gt;
 *         &lt;element ref="{urn:oasis:names:tc:SAML:1.0:assertion}AudienceRestrictionCondition"/&gt;
 *         &lt;element ref="{urn:oasis:names:tc:SAML:1.0:assertion}DoNotCacheCondition"/&gt;
 *         &lt;element ref="{urn:oasis:names:tc:SAML:1.0:assertion}Condition"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attribute name="NotBefore" type="{http://www.w3.org/2001/XMLSchema}dateTime" /&gt;
 *       &lt;attribute name="NotOnOrAfter" type="{http://www.w3.org/2001/XMLSchema}dateTime" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 */
public interface Conditions {
    
    /**
     * Gets the value of the notBefore property.
     * 
     * @return object is {@link java.util.Date }
     *     
     */
    public Date getNotBeforeDate();
    
    /**
     * Gets the value of the notOnOrAfter property.
     * 
     * @return object is {@link java.util.Date }
     *     
     */
    public Date getNotOnOrAfterDate();
    
     /**
     * Gets the value of the audienceRestrictionConditionOrDoNotCacheConditionOrCondition property.
     *
     * @return Objects of the following type(s) are in the list
     * {@link DoNotCacheCondition }
     * {@link AudienceRestrictionCondition }
     * {@link Condition }
     * 
     * 
     */
    List<Object> getConditions();
    
}

==> wssx-impl-4.0.1-sources.jar: com/sun/xml/wss/saml/Conditions.java <==
/*
 * Copyright (c) 2010, 2022 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0, which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/*
 * Conditions.java
 *
 * Created on August 18, 2005, 12:31 PM
 *
 */

package com.sun.xml.wss.saml;

import java.util.Date;
import java.util.List;

/**
 * The validity of an <code>Assertion</code> MAY be subject to a set of
 * <code>Conditions</code>. Each <code>Condition</code> evaluates to a value that
 * is Valid, Invalid or Indeterminate.
 *
 * <p>The following schema fragment specifies the expected content contained within
 * SAML Conditions element.
 *
 * <pre>
 * &lt;complexType name="ConditionsType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice maxOccurs="unbounded" minOccurs="0"&gt;
 *         &lt;element ref="{urn:oasis:names:tc:SAML:1.0:assertion}AudienceRestrictionCondition"/&gt;
 *         &lt;element ref="{urn:oasis:names:tc:SAML:1.0:assertion}DoNotCacheCondition"/&gt;
 *         &lt;element ref="{urn:oasis:names:tc:SAML:1.0:assertion}Condition"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attribute name="NotBefore" type="{http://www.w3.org/2001/XMLSchema}dateTime" /&gt;
 *       &lt;attribute name="NotOnOrAfter" type="{http://www.w3.org/2001/XMLSchema}dateTime" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 */
public interface Conditions {

    /**
     * Gets the value of the notBefore property.
     *
     * @return object is {@link java.util.Date }
     *
     */
    Date getNotBeforeDate();

    /**
     * Gets the value of the notOnOrAfter property.
     *
     * @return object is {@link java.util.Date }
     *
     */
    Date getNotOnOrAfterDate();

     /**
     * Gets the value of the audienceRestrictionConditionOrDoNotCacheConditionOrCondition property.
     *
     * @return Objects of the following type(s) are in the list
     * {@link DoNotCacheCondition }
     * {@link AudienceRestrictionCondition }
     * {@link Condition }
     *
     *
     */
    List<Object> getConditions();

}
